==> pyiArduinoI2Cbumper-0.0.1.tar.gz: pyiArduinoI2Cbumper-0.0.1/pyiArduinoI2Cbumper/examples/changeLineTypeAuto.py <==
# Пример автомотической смены типа линии трассы:            #
                                                            #
from pyiArduinoI2Cbumper import *                           #   Подключаем библиотеку для работы с бампером I2C-flash.
bum = pyiArduinoI2Cbumper(0x09)                             #   Объявляем объект bum для работы с функциями и методами библиотеки pyiArduinoI2Cbumper, указывая адрес модуля на шине I2C.
                                                            #   Если объявить объект без указания адреса bum = pyiArduinoI2Cbumper(), то адрес будет найден автоматически.
void loop(){                                               #
    uint16_t a                                             # * Объявляем переменную для получения флагов состояния всех датчиков линий.
#  Меняем тип трассы если изменился цвет линии:           #
    if( bum.getLineSum(a)>4 ){                             #   Если больше 4 датчиков бампера фиксируют линию, то ...
        bum.setLineType(BUM_LINE_CHANGE)                   #   Меняем тип линии трассы.
        a=~a                                               #   Меняем флаги состояния датчиков бампера.
        println("Выполнена смена типа трассы.")     #   Выводим текст.
    }                                                      #
#  Выводим номера датчиков под которыми есть линия:       # *
    if(a){print("Линия под датчиком:") }            # * Выводим текст.
    else {print("Линия не найдена"   ) }            # * Выводим текст.
    if( a & bit(1) ){ print(" 1")  }                # * Выводим номер 1 датчика, если под ним находится линия.
    if( a & bit(2) ){ print(" 2")  }                # * Выводим номер 2 датчика, если под ним находится линия.
    if( a & bit(3) ){ print(" 3")  }                # * Выводим номер 3 датчика, если под ним находится линия.
    if( a & bit(4) ){ print(" 4")  }                # * Выводим номер 4 датчика, если под ним находится линия.
    if( a & bit(5) ){ print(" 5")  }                # * Выводим номер 5 датчика, если под ним находится линия.
    if( a & bit(6) ){ print(" 6")  }                # * Выводим номер 6 датчика, если под ним находится линия.
    if( a & bit(7) ){ print(" 7")  }                # * Выводим номер 7 датчика, если под ним находится линия.
    if( a & bit(8) ){ print(" 8")  }                # * Выводим номер 8 датчика, если под ним находится линия.
    if( a & bit(9) ){ print(" 9")  }                # * Выводим номер 9 датчика, если под ним находится линия.
    println(".")                                    # * Завершаем строку.
}                                                          #

==> pyiArduinoI2Cbumper-1.0.2.tar.gz: pyiArduinoI2Cbumper-1.0.2/pyiArduinoI2Cbumper/examples/changeLineTypeAuto.py <==
# Пример автомотической смены типа линии трассы:            #

from time import sleep
                                                            #
#   Подключаем библиотеку для работы с бампером I2C-flash.
from pyiArduinoI2Cbumper import *
#   Объявляем объект для работы с функциями и методами
#   библиотеки pyiArduinoI2Cbumper, указывая адрес модуля на шине I2C.
bum = pyiArduinoI2Cbumper(0x09)

while True:
    a = 0
    b = bum.getLineSum(a)
#    print(b[1])
    if b[0] > 4:
        bum.setLineType(BUM_LINE_CHANGE)
        print("Выполнена смена типа трассы.")
    sleep(.01)

"""
#  Меняем тип трассы если изменился цвет линии:           #

    if bum.getLineSum(a)>4 ){                             #   Если больше 4 датчиков бампера фиксируют линию, то ...
        bum.setLineType(BUM_LINE_CHANGE)                   #   Меняем тип линии трассы.
        a=~a                                               #   Меняем флаги состояния датчиков бампера.
    }                                                      #
"""
"""
#  Выводим номера датчиков под которыми есть линия:       # *
    if(a){print("Линия под датчиком:") }            # * Выводим текст.
    else {print("Линия не найдена"   ) }            # * Выводим текст.
    if( a & bit(1) ){ print(" 1")  }                # * Выводим номер 1 датчика, если под ним находится линия.
    if( a & bit(2) ){ print(" 2")  }                # * Выводим номер 2 датчика, если под ним находится линия.
    if( a & bit(3) ){ print(" 3")  }                # * Выводим номер 3 датчика, если под ним находится линия.
    if( a & bit(4) ){ print(" 4")  }                # * Выводим номер 4 датчика, если под ним находится линия.
    if( a & bit(5) ){ print(" 5")  }                # * Выводим номер 5 датчика, если под ним находится линия.
    if( a & bit(6) ){ print(" 6")  }                # * Выводим номер 6 датчика, если под ним находится линия.
    if( a & bit(7) ){ print(" 7")  }                # * Выводим номер 7 датчика, если под ним находится линия.
    if( a & bit(8) ){ print(" 8")  }                # * Выводим номер 8 датчика, если под ним находится линия.
    if( a & bit(9) ){ print(" 9")  }                # * Выводим номер 9 датчика, если под ним находится линия.
    println(".")                                    # * Завершаем строку.
}                                                          #
"""
